%define anolis_release 2

%global shared_requirements \
Requires:         bash                       \
Requires:         filesystem          >= 3   \
Requires:         coreutils                  \
Requires:         gawk                       \

Name:             initscripts
Summary:          Basic support for legacy System V init scripts
Version:          10.17
Release:          %{anolis_release}%{?dist}

License:          GPLv2

URL:              https://github.com/fedora-sysv/initscripts
Source:           https://github.com/fedora-sysv/initscripts/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz

%shared_requirements

Requires:         findutils
Requires:         grep
Requires:         procps-ng
Requires:         setup
Requires:         systemd
Requires:         util-linux
Requires:         chkconfig
Requires:         initscripts-service
Requires:         initscripts-rename-device

Requires(pre):    shadow-utils
Requires(post):   coreutils

BuildRequires:    filesystem          >= 3
BuildRequires:    gcc
BuildRequires:    git
BuildRequires:    gettext
BuildRequires:    glib2-devel
BuildRequires:    pkgconfig
BuildRequires:    popt-devel
BuildRequires:    setup
BuildRequires:    make

%{?systemd_requires}
BuildRequires:    systemd

Obsoletes:        %{name}            < 10.16-1

%description
This package provides basic support for legacy System V init scripts, and some
other legacy tools & utilities.

%package -n initscripts-rename-device
Summary:          Udev helper utility that provides network interface naming

%shared_requirements

%description -n initscripts-rename-device
Udev helper utility that provides network interface naming

%package -n initscripts-service
Summary:          Support for service command
BuildArch:        noarch

%shared_requirements

Requires:         systemd

Provides:         /sbin/service

%description -n initscripts-service
This package provides service command.

%package -n network-scripts
Summary:          Legacy scripts for manipulating of network devices
Requires:         %{name} = %{version}-%{release}

%shared_requirements

Requires:         bc
Requires:         dbus
Requires:         dbus-tools
Requires:         gawk
Requires:         grep
Requires:         hostname
Requires:         iproute
Requires:         ipcalc
Requires:         kmod
Requires:         procps-ng
Requires:         sed
Requires:         systemd

Requires(post):   chkconfig
Requires(preun):  chkconfig

Requires(post):   %{_sbindir}/update-alternatives
Requires(postun): %{_sbindir}/update-alternatives

Obsoletes:        %{name}            < 9.82-2

# Mark this as deprecated to ensure not be depended.
Provides:         deprecated()

%description -n network-scripts
This package contains the legacy scripts for activating & deactivating of most
network interfaces. It also provides a legacy version of 'network' service.

The 'network' service is enabled by default after installation of this package,
and if the network-scripts are installed alongside NetworkManager, then the
ifup/ifdown commands from network-scripts take precedence over the ones provided
by NetworkManager.

If user has both network-scripts & NetworkManager installed, and wishes to
use ifup/ifdown from NetworkManager primarily, then they has to run command:
 $ update-alternatives --config ifup

Please note that running the command above will also disable the 'network'
service.

%package -n netconsole-service
Summary:          Service for initializing of network console logging
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

Requires:         glibc-common
Requires:         iproute
Requires:         iputils
Requires:         kmod
Requires:         sed
Requires:         util-linux

Obsoletes:        %{name}            < 9.82-2

%description -n netconsole-service
This packages provides a 'netconsole' service for loading of netconsole kernel
module with the configured parameters. The netconsole kernel module itself then
allows logging of kernel messages over the network.

%package -n readonly-root
Summary:          Service for configuring read-only root support
Requires:         %{name} = %{version}-%{release}
BuildArch:        noarch

%shared_requirements

Requires:         cpio
Requires:         findutils
Requires:         hostname
Requires:         iproute
Requires:         ipcalc
Requires:         util-linux

Obsoletes:        %{name}            < 9.82-2

%description -n readonly-root
This package provides script & configuration file for setting up read-only root
support. Additional configuration is required after installation.

Please note that readonly-root package is considered deprecated with limited support.
Please use systemd-volatile-root functionality instead, if possible.

%prep
%autosetup -S git

%build
%make_build PYTHON=%{__python3}

%install
%make_install

%find_lang %{name}

rm -f %{buildroot}%{_sysconfdir}/sysconfig/network-scripts/ifup-ctc

install -m 0755 -d %{buildroot}%{_docdir}/network-scripts

ln -s  %{_docdir}/%{name}/sysconfig.txt %{buildroot}%{_docdir}/network-scripts/
ln -sr %{_mandir}/man8/ifup.8           %{buildroot}%{_mandir}/man8/ifdown.8

touch %{buildroot}%{_sbindir}/ifup
touch %{buildroot}%{_sbindir}/ifdown

%generate_compatibility_deps

%post
%systemd_post import-state.service loadmodules.service

%preun
%systemd_preun import-state.service loadmodules.service

%postun
%systemd_postun import-state.service loadmodules.service

%post -n network-scripts
chkconfig --add network > /dev/null 2>&1 || :

[ -L %{_sbindir}/ifup ]   || rm -f %{_sbindir}/ifup
[ -L %{_sbindir}/ifdown ] || rm -f %{_sbindir}/ifdown

%{_sbindir}/update-alternatives --install %{_sbindir}/ifup   ifup   %{_sysconfdir}/sysconfig/network-scripts/ifup 90 \
                                --slave   %{_sbindir}/ifdown ifdown %{_sysconfdir}/sysconfig/network-scripts/ifdown \
                                --initscript network

%preun -n network-scripts
if [ $1 -eq 0 ]; then
  chkconfig --del network > /dev/null 2>&1 || :
  %{_sbindir}/update-alternatives --remove ifup %{_sysconfdir}/sysconfig/network-scripts/ifup
fi

%post -n netconsole-service
%systemd_post netconsole.service

%preun -n netconsole-service
%systemd_preun netconsole.service

%postun -n netconsole-service
%systemd_postun netconsole.service

%post -n readonly-root
%systemd_post readonly-root.service

%preun -n readonly-root
%systemd_preun readonly-root.service

%postun -n readonly-root
%systemd_postun readonly-root.service

%files -f %{name}.lang
%dir %{abidir}
%license COPYING
%doc doc/sysconfig.txt

# NOTE: /etc/profile.d/ is owned by setup package.
#       /etc/sysconfig/ is owned by filesystem package.
%dir %{_sysconfdir}/rc.d
%dir %{_sysconfdir}/rc.d/init.d
%dir %{_sysconfdir}/rc.d/rc[0-6].d
%dir %{_sysconfdir}/sysconfig/console
%dir %{_sysconfdir}/sysconfig/modules
%dir %{_libexecdir}/%{name}
%dir %{_libexecdir}/%{name}/legacy-actions
%{_sysconfdir}/rc.d/init.d/functions
%{_sysconfdir}/rc[0-6].d
%{_sysconfdir}/init.d
%{_bindir}/*
%{abidir}/*-option.list
%{_sbindir}/consoletype
%{_sbindir}/genhostid
%{_libexecdir}/import-state
%{_libexecdir}/loadmodules
%{_prefix}/lib/systemd/system/import-state.service
%{_prefix}/lib/systemd/system/loadmodules.service
%{_mandir}/man1/*

%files -n initscripts-rename-device
%{_prefix}/lib/udev/rename_device
%{_udevrulesdir}/*

%files -n initscripts-service
%dir %{_libexecdir}/%{name}
%dir %{_libexecdir}/%{name}/legacy-actions
%{_sbindir}/service
%{_mandir}/man8/service.*

%files -n network-scripts
%doc doc/examples/
%dir %{_sysconfdir}/sysconfig/network-scripts
%{_sysconfdir}/rc.d/init.d/network
%{_sysconfdir}/sysconfig/network-scripts/*
%config(noreplace)    %{_sysconfdir}/sysconfig/network-scripts/ifcfg-lo
%ghost                %{_sbindir}/ifup
%ghost                %{_sbindir}/ifdown
%attr(4755,root,root) %{_sbindir}/usernetctl
%{_mandir}/man8/ifup.*
%{_mandir}/man8/ifdown.*
%{_mandir}/man8/usernetctl.*
%{_docdir}/network-scripts/*

%files -n netconsole-service
%config(noreplace) %{_sysconfdir}/sysconfig/netconsole
%{_libexecdir}/netconsole
%{_prefix}/lib/systemd/system/netconsole.service

%files -n readonly-root
%dir %{_sharedstatedir}/stateless
%dir %{_sharedstatedir}/stateless/state
%dir %{_sharedstatedir}/stateless/writable
%config(noreplace) %{_sysconfdir}/rwtab
%config(noreplace) %{_sysconfdir}/statetab
%config(noreplace) %{_sysconfdir}/sysconfig/readonly-root
%{_libexecdir}/readonly-root
%{_prefix}/lib/systemd/system/readonly-root.service

%changelog
* Wed Oct 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 10.17-2
- optimise spec file

* Fri Sep 23 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 10.17-1
- update to 10.17

* Tue Mar 08 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 10.16-1
- init from upstream 10.16
